; *******************************
; ***** ISD1760 Interface  *****
; *******************************
;    Filename: 		ISD1760.bas	
;    Date: 			Feb 6, 2016		
;    File Version: 	1.0	
;    Written by: 		Simon Carter	
;    Function:		SPI Control of ISD1760		
;    Last Revision:	1.0
;    Target PICAXE:	20X2	
; ******************************* 

' PINS Set up:
' C.0 SS
' C.1 SDO to MOSI ISD1760
' B.5 SDI to MISO ISD1760
' B.7 SCLK

' ***** Directives *****

#com 3						' specify the serial port to be used
#picaxe 20X2					' specify the processor

' ***** Constants & Variables *****

symbol CS = C.0					' chip select pin				
symbol i = b1					' counter i			
symbol k = b2					' counter k

' ***** Main Program *****

do
for i = 1 to 5					' for count of five; play 5 sound clips

gosub Rst						' goto Reset subroutine
gosub PU						' goto ISD1760 power up subroutine

if i = 1 then let b3 = 9 endif		' set number of fwd commands
if i = 2 then let b3 = 4 endif		' set number of fwd commands
if i = 3 then let b3 = 10 endif		' set number of fwd commands
if i = 4 then let b3 = 1 endif		' set number of fwd commands
if i = 5 then let b3 = 11 endif		' set number of fwd commands
gosub Fwd						' goto Fwd subroutine
gosub Ply						' goto Play recording subroutine
next i
loop

Rst:							' ISD1760 Reset routine

Low CS						' select ISD1760
let b0 = 0x03					' set b0 to first byte of reset command
spiout B.7, C.1, LSBFirst_L, (b0/8)		' send first byte, LSB first, 8 bits
let b0 = 0x00					' set b0 to second byte of reset command
spiout B.7, C.1, LSBFirst_L, (b0/8)		' send second byte, LSB first, 8 bits
High CS						' de-select ISD1760
return

PU:							' ISD1760 Power Up routine

Low CS						' select ISD1760
let b0 = 0x01					' set b0 to first byte of PU command
spiout B.7, C.1, LSBFirst_L, (b0/8)		' send first byte, LSB first, 8 bits
let b0 = 0x00					' set b0 to second byte of PU command
spiout B.7, C.1, LSBFirst_L, (b0/8)		' send second byte, LSB first, 8 bits
High CS						' de-select ISD1760
return

Ply:							' ISD1760 Play routine

Low CS						' select ISD1760
let b0 = 0x40					' set b0 to first byte of Play command
spiout B.7, C.1, LSBFirst_L, (b0/8)		' send first byte, LSB first, 8 bits
let b0 = 0x00					' set b0 to second byte of Play command
spiout B.7, C.1, LSBFirst_L, (b0/8)		' send second byte, LSB first, 8 bits
High CS						' de-select ISD1760
pause 1500						' wait 1.5 second for message to play
return

Fwd:							' ISD1760 Forward to next message routine
if b3 = 0 then return endif			' if b3 = 0 then do nothing
for k = 1 to b3					' Fwd b3 number of times
Low CS						' select ISD1760
let b0 = 0x48					' set b0 to first byte of Fwd command
spiout B.7, C.1, LSBFirst_L, (b0/8)		' send first byte, LSB first, 8 bits
let b0 = 0x00					' set b0 to second byte of Fwd command
spiout B.7, C.1, LSBFirst_L, (b0/8)		' send second byte, LSB first, 8 bits
High CS						' de-select ISD1760
next k
return
end